@@ -59,6 +59,7 @@ log.addHandler(c)
 class Ui(object):
 
     def __init__(self):
+        self.file_crypt = FileCrypt()
         if sys.platform == 'win32':
             log.debug('Working on windows')
             self._clear = 'cls'
@@ -73,6 +74,16 @@ class Ui(object):
             log.error(e, exc_info=True)
             self.config = SetupConfig()
         self.nst = NotSoTuf(__name__, self.config)
+        self.key_handler = KeyHandler()
+        self.package_handler = PackageHandler()
+        self.uploader = Uploader()
+        self.update_mods(self.nst)
+
+    def update_mods(self, nst):
+        self.key_handler.init_app(nst)
+        self.package_handler.init_app(nst)
+        self.uploader.init_app(nst)
+        log.debug('Module updates complete')
 
     def main(self):
         log.debug('Main menu')
@@ -103,19 +114,16 @@ class Ui(object):
         log.debug('Signing updates')
         print(app_header('Signing updates...'))
         print(format_msg('Please wait...'))
-        package_handler = PackageHandler(self.nst)
-        package_handler.setup()
-        package_handler.update_package_list()
-        key_handler = KeyHandler(self.nst)
-        key_handler.sign_update()
-        package_handler.deploy()
+        self.package_handler.setup()
+        self.package_handler.update_package_list()
+        self.key_handler.sign_update()
+        self.package_handler.deploy()
         print('Update signing complete...')
         time.sleep(3)
         self.main()
 
     def upload(self):
         log.debug('Upload')
-        self.uploader = Uploader(self.nst)
         print(app_header('Upload'))
         msg = ('Select destination to begin upload.  If you don\'t have any '
                'upload settings, go to settings menu, then update settings or '
@@ -171,28 +179,27 @@ class Ui(object):
 
     def show_public_key(self):
         log.debug('Show public key')
-        key_handler = KeyHandler(self.nst)
-        key_handler.print_public_key()
+        self.key_handler.print_public_key()
         raw_input(format_msg('Press enter to continue'))
         self.keys()
 
     def private_key_copy(self):
         log.debug('Copied private key')
-        key_handler = KeyHandler(self.nst)
-        key_handler.copy_decrypted_private_key()
+        self.key_handler.copy_decrypted_private_key(self.file_crypt)
         msg = 'Private key decrypted. Press enter to continue'
         raw_input(format_msg(msg))
         self.keys()
 
     def replace_keys(self):
         log.debug('Replacing keys')
-        key_handler = KeyHandler(self.nst)
-        key_handler.make_keys(overwrite=True)
+        self.key_handler.make_keys(overwrite=True)
 
     def make_keys(self):
         log.debug('Making keys')
-        key_handler = KeyHandler(self.nst)
-        key_handler.make_keys()
+        self.key_handler.make_keys()
+        pub_key = self.key_handler.get_public_key()
+        self.config.PUBLIC_KEY = pub_key
+        self.save_config(self.config)
 
     def settings(self):
         log.debug('Settings Menu')
@@ -230,23 +237,21 @@ class Ui(object):
 
             log.debug('Attempting to copy decrypted config')
             filename = os.path.join(_cwd, 'config.data')
-            fc = FileCrypt(filename)
-            fc.decrypt()
+            self.file_crypt.new_file(filename)
+            self.file_crypt.decrypt()
             try:
                 shutil.copy(filename, filename + ' copy')
                 log.debug('Copied config')
             except Exception as e:
                 log.error(str(e), exc_info=True)
                 log.error('Cannot copy decrypted config file')
-            fc.encrypt()
+            self.file_crypt.encrypt()
             msg = ('Decrypted config file & private key copied.'
                    'Press enter to continue')
             log.debug('Copied private key')
-            key_handler = KeyHandler(self.nst)
-            key_handler.copy_decrypted_private_key()
+            self.key_handler.copy_decrypted_private_key()
             raw_input(format_msg(msg))
-        fc = FileCrypt()
-        fc.del_folder_password()
+        self.file_crypt.del_folder_password()
         print('Folder password deleted')
 
     def view_settings(self):
@@ -343,10 +348,15 @@ class Ui(object):
         dev_data_dir = _directory_fixer(dev_data_dir)
 
         self.config.DEV_DATA_DIR = path_fixer(dev_data_dir)
-        self.config.KEY_LENGTH = get_correct_answer('Enter a key length. '
-                                                    'Longer is more secure '
-                                                    'but takes longer to '
-                                                    'compute!', default='2048')
+        while 1:
+            key_length = get_correct_answer('Enter a key length. Longer is '
+                                            'more secure but takes longer '
+                                            'to compute. Must be multiple '
+                                            'of 256!', default='2048')
+            if int(key_length) % 256 == 0:
+                self.config.KEY_LENGTH = key_length
+                break
+
         priv_key_name = get_correct_answer('Enter a name to give '
                                            'your private key',
                                            default='Not-So-TUF')
@@ -405,8 +415,7 @@ class Ui(object):
                                                           required=True)
 
         self.save_config(self.config)
-        package_handler = PackageHandler(self.nst)
-        package_handler.setup()
+        self.package_handler.setup()
         print('Making keys...')
         self.make_keys()
         print(app_header('Setup Complete'))
@@ -415,37 +424,38 @@ class Ui(object):
 
     def save_config(self, obj):
         self.nst.update_config(obj)
+        self.update_mods(self.nst)
         log.debug('Saving Config')
         filename = os.path.join(_cwd, 'config.data')
-        fc = FileCrypt(filename)
-        fc.decrypt()
+        self.file_crypt.new_file(filename)
+        self.file_crypt.decrypt()
         with open(filename, 'w') as f:
             f.write(pickle.dumps(obj))
-        fc.encrypt()
-        write_client_config(self.nst)
+        self.file_crypt.encrypt()
+        write_client_config(obj)
 
     def load_config(self):
         log.debug('Loading Config')
         filename = os.path.join(_cwd, 'config.data')
-        fc = FileCrypt(filename)
-        fc.decrypt()
+        self.file_crypt.new_file(filename)
+        self.file_crypt.decrypt()
         with open(filename, 'r') as f:
             config_data = pickle.loads(f.read())
-        fc.encrypt()
+        self.file_crypt.encrypt()
         write_client_config(config_data)
         return config_data
 
     def copy_decrypted_config(self):
         log.debug('Attempting to copy decrypted config')
         filename = os.path.join(_cwd, 'config.data')
-        fc = FileCrypt(filename)
-        fc.decrypt()
+        self.file_crypt.new_file(filename)
+        self.file_crypt.decrypt()
         try:
             shutil.copy(filename, filename + ' copy')
         except Exception as e:
             log.error(str(e), exc_info=True)
             log.error('Cannot copy decrypted config file')
-        fc.encrypt()
+        self.file_crypt.encrypt()
         msg = 'Decrypted config file copied.  Press enter to continue'
         raw_input(format_msg(msg))
         self.settings()
