@@ -215,7 +215,7 @@ def write_client_config(config_object, test=False):
 # If there is a better way to do this please chime in!
 def dev_machine_check():
     files = os.listdir(os.getcwd())
-    if 'app.py' in files and 'make_binary.py' in files:
+    if 'app.py' in files and 'requirments.txt' in files:
         log.debug('We are on the dev machine.')
         return logging.DEBUG
     else:
