@@ -34,6 +34,8 @@ from not_so_tuf.package_handler import PackageHandler
 from not_so_tuf.patcher import Patcher
 from not_so_tuf.uploader import Uploader
 
+from not_so_tuf.exceptions import NotSoTufError
+
 
 class NotSoTuf(object):
     """There are 2 ways to load config.  The first was is during
@@ -41,9 +43,6 @@ class NotSoTuf(object):
 
     Examples are shown below::
 
-        DEBUG = True
-        SECRET_KEY = 'development key'
-        app.config.from_object(__name__)
         Config(object):
             APP_NAME = "NST"
 
@@ -51,9 +50,9 @@ class NotSoTuf(object):
 
             UPDATE_URL = http://www.test-nst.com/updates
 
-        app = NotSoTuf(Config())
+        app = NotSoTuf(__name__, Config())
 
-        app = NotSoTuf()
+        app = NotSoTuf(__name__)
         app.update_config(Config())
 
     Kwargs:
@@ -63,8 +62,8 @@ class NotSoTuf(object):
     """
     def __init__(self, import_name=None, cfg_obj=None):
         if import_name is None:
-            raise UpdaterError(u'You have to pass __name__ to Updater',
-                               expected=True)
+            raise NotSoTufError(u'You have to pass __name__ to '
+                                'NotSoTuf(__name__)', expected=True)
         self.import_name = import_name
         self.real_path = os.path.dirname(os.path.abspath(self.import_name))
         self.config = Config()
