@@ -162,6 +162,12 @@ class Client(object):
                                          filename)
 
     def _move_restart(self):
+        """Unix: Overwrites the running applications binary, then starts
+        the updated binary in the currently running applications process
+        memory.
+
+        Windows: Moves update to current directory of running application
+        then restarts application using new update."""
         _dir = os.path.dirname(sys.argv[0])
         current_app = os.path.join(_dir, self.fixed_filename)
         updated_app = os.path.join(self.update_folder, self.fixed_filename)
